@@ -369,15 +369,27 @@ function drawTexts(g, gd) {
         traceIndex = trace.index,
         name = isPie ? legendItem.label : trace.name;
 
+    var labels = (typeof name === 'string') ? [name] : name
+    if(legendItem.trace.labels){
+      labels = legendItem.trace.labels[legendItem.i]
+    }
+
+
     var text = g.selectAll('text.legendtext')
         .data([0]);
-
     text.enter().append('text').classed('legendtext', true);
-
     text.attr('text-anchor', 'start')
         .classed('user-select-none', true)
         .call(Drawing.font, fullLayout.legend.font)
-        .text(name);
+        .text(labels[0]);
+
+    var textValue = g.selectAll('text.legendvalue')
+        .data([1]);
+    textValue.enter().append('text').classed('legendvalue', true);
+    textValue.attr('text-anchor', 'start')
+        .classed('user-select-none', true)
+        .call(Drawing.font, fullLayout.legend.font)
+        .text((labels[1]) ? labels[1] : '');
 
     function textLayout(s) {
         svgTextUtils.convertToTspans(s, gd, function() {
@@ -429,7 +441,10 @@ function drawTexts(g, gd) {
                 return Plotly.restyle(gd, update, traceIndex);
             });
     }
-    else text.call(textLayout);
+    else {
+      text.call(textLayout);
+      textValue.call(textLayout);
+    }
 }
 
 function setupTraceToggle(g, gd) {
@@ -605,6 +620,14 @@ function computeTextDimensions(g, gd) {
         // TODO: this 40 should go in a constants file (along with other
         // values related to the legend symbol size)
         svgTextUtils.positionText(text, 40, textY);
+
+
+        var textValue = g.select('.legendvalue');
+        var textValueNode = text.node();
+        var valueWidth = 50;
+
+        svgTextUtils.positionText(textValue, (width + valueWidth), textY);
+        width = width + valueWidth
     }
 
     height = Math.max(height, 16) + 3;
